@@ -29,7 +29,8 @@ try {// Load root from config file.  Error if missing or unable to determine api
     alert('missing or corrupt config.js file');
 }
 
-var language = language ? getURLParameter('lang').replace(/\./g,'') : 'en-US';
+
+var language = getURLParameter('lang') ? getURLParameter('lang').replace(/\./g,'') : 'en-US';
 templid = parseInt(getURLParameter("templid"));
 if (templid == null || isNaN(parseInt(templid))) {   // If no clean template ID, see if we have a default from config.js
     try {
